# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.0] - 2026-02-08

### Added

- Initial release of `arxivy`
- `search`, `paper`, `bibtex`, and `new` commands for the arXiv API
- Human-friendly Rich tables/panels in terminals
- Machine-friendly JSON output (pretty on TTY, compact when piped)
- BibTeX export with LaTeX escaping and citation key generation
- Proactive throttling (arXiv-friendly) and retry/backoff behavior (including 429)
- Secure Atom feed parsing via `defusedxml`

[Unreleased]: https://github.com/mrshu/arxivy/compare/v0.1.0...HEAD
[0.1.0]: https://github.com/mrshu/arxivy/releases/tag/v0.1.0
